﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;

namespace QuickZDLSharp
{
    public partial class frmConfigure : Form
    {

        private List<string> IWADs;
        private List<string> Engines;

        public frmConfigure(List<string> iIWADs, List<string> iEngines)
        {
            InitializeComponent();

            IWADs = iIWADs;
            Engines = iEngines;

            UpdateLists();
        }

        /// <summary>
        /// Update the engines and iwads list views.
        /// This function takes each item in IWADs and Engines and adds it into the lists
        /// </summary>
        private void UpdateLists()
        {
            lvEngines.Items.Clear();
            lvIWADs.Items.Clear();

            foreach(string tIwadName in IWADs)
            {
                ListViewItem tItem = new ListViewItem();
                tItem.Text = tIwadName;
                lvIWADs.Items.Add(tItem);

            }

            foreach(string tEngineName in Engines)
            {
                ListViewItem tItem = new ListViewItem();
                tItem.Text = tEngineName;
                lvEngines.Items.Add(tItem);

            }
        }

        // according to the Internet if I allow friend field access, IDL Ninjas will
        // be sent to my house.
        //
        // See guys? I did it this time... 
        internal  List<string> GetIWADs()
        {
            return IWADs;
        }

        internal List<string> GetEngines()
        {
            return Engines;
        }

        private void AddEnginePB_Click(object sender, EventArgs e)
        {
            DialogResult tResult;
            tResult = dlgOpenEngine.ShowDialog();

            if(tResult != DialogResult.OK)
            {
                return;
            }

            string tSelectedPath = dlgOpenEngine.FileName;

            Engines.Add(tSelectedPath);

            UpdateLists();
        }

        private void RemoveEnginePB_Click(object sender, EventArgs e)
        {
            // nothing to do if they haven't selected anything.
            if(lvEngines.SelectedItems.Count < 1)
            {
                return;
            }

            // get the first item they selected -- they should only be able to select one...
            ListViewItem tSelectedItem = lvEngines.SelectedItems[0];

            string tPathToDelete = tSelectedItem.Text;

            Engines.Remove(tPathToDelete);

            UpdateLists();
        }

        private void AddIWADPB_Click(object sender, EventArgs e)
        {
            DialogResult tResult;
            tResult = dlgOpenIWAD.ShowDialog();

            if(tResult != DialogResult.OK)
            {
                return;
            }

            string tSelectedPath = dlgOpenIWAD.FileName;

            IWADs.Add(tSelectedPath);

            UpdateLists();
        }

        private void RemoveIWADPB_Click(object sender, EventArgs e)
        {
            // nothing to do if they haven't selected anything.
            if(lvIWADs.SelectedItems.Count < 1)
            {
                return;
            }

            // get the first item they selected -- they should only be able to select one...
            ListViewItem tSelectedItem = lvIWADs.SelectedItems[0];

            string tPathToDelete = tSelectedItem.Text;

            IWADs.Remove(tPathToDelete);

            UpdateLists();
        }

        private void CancelPB_Click(object sender, EventArgs e)
        {
            // note: this automatically exits out of the dialog when I set this dialog's DialogResult to something
            this.DialogResult = DialogResult.Cancel;
        }

        private void OKPB_Click(object sender, EventArgs e)
        {
            // note: this automatically exits out of the dialog when I set this dialog's DialogResult to something
            this.DialogResult = DialogResult.OK;
        }
    }

    
}
