﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;

namespace QuickZDLSharp
{
    public partial class frmMain : Form
    {
        private List<string> IWADs;
        private List<string> Engines;
        private List<string> PWADs;

        public frmMain()
        {
            InitializeComponent();

            IWADs = new List<string>();
            Engines = new List<string>();
            PWADs = new List<string>();
        }

        private void ConfigurePB_Click(object sender, EventArgs e)
        {
            frmConfigure tConfigure = new frmConfigure(IWADs, Engines);

            DialogResult tResult;

            tResult = tConfigure.ShowDialog();

            if(tResult != DialogResult.OK)
            {
                return;
            }           

            IWADs = tConfigure.GetIWADs();
            Engines = tConfigure.GetEngines();

            LoadLists();


        }

        private void LoadLists()
        {
            cboSourcePort.Items.Clear();
            lvExternalFiles.Items.Clear();
            lvIWADs.Items.Clear();

            foreach(string tIwadName in IWADs)
            {
                ListViewItem tItem = new ListViewItem();
                tItem.Text = tIwadName;
                lvIWADs.Items.Add(tItem);

            }

            foreach(string tPwadName in PWADs)
            {
                ListViewItem tItem = new ListViewItem();
                tItem.Text = tPwadName;
                lvExternalFiles.Items.Add(tItem);
            }

            foreach(string tSourcePortName in Engines)
            {
                cboSourcePort.Items.Add(tSourcePortName);
            }

            // try to find a source port to select for them, so that newly added source ports
            // get selected automatically, rather than useless blank selections
            if((cboSourcePort.SelectedIndex < 0) && (cboSourcePort.Items.Count > 0))
            {
                cboSourcePort.SelectedIndex = 0;
            }

            // if we deleted the last engine, clear out the combo box to not confuse people
            if(cboSourcePort.Items.Count < 1)
            {
                cboSourcePort.Text = "";
                cboSourcePort.SelectedIndex = -1;
            }
        }

        private void AddFilePB_Click(object sender, EventArgs e)
        {
            DialogResult tDialogResult;

            tDialogResult = dlgOpenPWADThing.ShowDialog();

            // don't bother doing anything else if the user hit cancel...
            if(tDialogResult != DialogResult.OK)
            {
                return;
            }


            string tSelectedPath = dlgOpenPWADThing.FileName;    
 
            PWADs.Add(tSelectedPath);

            LoadLists();
        }

        private void RemoveFilePB_Click(object sender, EventArgs e)
        {
            if(lvExternalFiles.SelectedItems.Count < 1)
            {
                return;
            }

            ListViewItem tSelectedItem = lvExternalFiles.SelectedItems[0];
            string tPathToDelete = tSelectedItem.Text;

            PWADs.Remove(tPathToDelete);

            LoadLists();

        }

        private void LaunchPB_Click(object sender, EventArgs e)
        {
           
            if(lvIWADs.SelectedItems.Count < 1)
            {
                // can't run a game without an iwad selected
                return;
            }

            if(cboSourcePort.Items.Count < 1)
            {
                // can't start a game without source ports.
                return;
            }

            string tEnginePath = cboSourcePort.Text;
            
            ListViewItem tIWADItem = lvIWADs.SelectedItems[0];

            string tIwadPath = tIWADItem.Text;

            string tMapString = "";
            


            // now add the iwad


            // if the user specified a map, add +map <map name>
            if(txtMap.Text != "")
            {
                tMapString = "+MAP " + txtMap.Text;
            }



            int tSelectedSkill = cboSkill.SelectedIndex;
            
            string tArguments;

            // make the command
            tArguments =  " -iwad " + tIwadPath + " " + tMapString + " -skill " + tSelectedSkill.ToString();

            string tPwads = "";

            foreach(ListViewItem tPwadItem in lvExternalFiles.Items)
            {
                string tPwadPath = tPwadItem.Text;
                tPwads = tPwads + " -file " + tPwadPath;
            }

            // add the pwads to the arguments list.
            tArguments = tArguments + tPwads;

            System.Diagnostics.Process.Start(tEnginePath, tArguments);
        }

   

        private void ShowCommandPB_Click(object sender, EventArgs e)
        {
            if(lvIWADs.SelectedItems.Count < 1)
            {
                // can't run a game without an iwad selected
                return;
            }

            if(cboSourcePort.Items.Count < 1)
            {
                // can't start a game without source ports.
                return;
            }

            string tEnginePath = cboSourcePort.Text;
            
            ListViewItem tIWADItem = lvIWADs.SelectedItems[0];

            string tIwadPath = tIWADItem.Text;

            string tMapString = "";
            


            // now add the iwad


            // if the user specified a map, add +map <map name>
            if(txtMap.Text != "")
            {
                tMapString = "+MAP " + txtMap.Text;
            }



            int tSelectedSkill = cboSkill.SelectedIndex;
            
            string tCommand;
            string tArguments;

            tArguments =  " -iwad " + tIwadPath + " " + tMapString + " -skill " + tSelectedSkill.ToString();

            string tPwads = "";

            foreach(ListViewItem tPwadItem in lvExternalFiles.Items)
            {
                string tPwadPath = tPwadItem.Text;
                tPwads = tPwads + " -file " + tPwadPath;
            }

            // add the pwads to the arguments list.
            tArguments = tArguments + tPwads;

            // make the command
            tCommand = tEnginePath + tArguments;

            MessageBox.Show(tCommand);
        }
    }
}
